set_progress_handler_stderr

Function set_progress_handler_stderr 

pub fn set_progress_handler_stderr() -> ProgressHandlerGuard
Installs igraph’s predefined progress handler, which prints the message and the percentage to standard error, until the guard is dropped.

Binds igraph_progress_handler_stderr.