pub fn set_status_handler_stderr() -> StatusHandlerGuardExpand description
Installs igraph’s predefined status handler, which writes the messages to standard error, until the guard is dropped.
Binds igraph_status_handler_stderr.
pub fn set_status_handler_stderr() -> StatusHandlerGuardInstalls igraph’s predefined status handler, which writes the messages to standard error, until the guard is dropped.
Binds igraph_status_handler_stderr.