with_status_handler

Function with_status_handler 

pub fn with_status_handler<R>(
    handler: impl FnMut(&str) -> ControlFlow<()> + 'static,
    body: impl FnOnce() -> R,
) -> R
Runs body with handler installed as the status handler of the calling thread, restoring the previous handler afterwards. See set_status_handler.