ConvexHull

Struct ConvexHull 

pub struct ConvexHull {
    pub vertices: Vec<i64>,
    pub points: Vec<[f64; 2]>,
}
The convex hull of a 2D point set, as returned by convex_hull_2d.

Fields

vertices: Vec<i64>

The indices (rows of the input matrix) of the corners of the hull, in order along the boundary. Points in the interior of a side are not corners.

points: Vec<[f64; 2]>

The coordinates of the corners, in the same order as vertices.

Implementations

Source

impl ConvexHull

pub fn area(&self) -> f64

The (non-negative) area enclosed by the hull, by the shoelace formula.

pub fn perimeter(&self) -> f64

The perimeter of the hull.