pub fn set_progress_handler_stderr() -> ProgressHandlerGuardExpand description
Installs igraph’s predefined progress handler, which prints the message and the percentage to standard error, until the guard is dropped.
pub fn set_progress_handler_stderr() -> ProgressHandlerGuardInstalls igraph’s predefined progress handler, which prints the message and the percentage to standard error, until the guard is dropped.