pub struct ConvexHull {
pub vertices: Vec<i64>,
pub points: Vec<[f64; 2]>,
}Expand description
The convex hull of a 2D point set, as returned by convex_hull_2d.
Fields
vertices: Vec<i64>The indices (rows of the input matrix) of the corners of the hull, in order along the boundary. Points in the interior of a side are not corners.
points: Vec<[f64; 2]>The coordinates of the corners, in the same order as vertices.
Implementations