pub struct ProgressHandlerGuard { /* private fields */ }Expand description
Keeps a progress handler installed; returned by set_progress_handler
and set_progress_handler_stderr.
Dropping the guard uninstalls its handler: if it was the active one, the
handler of the most recent guard still alive (or, if none, the handler
that was active before the first guard) is reinstalled. Guards can be
dropped in any order, e.g. when kept in a struct or a Vec.
The guard is bound to the thread that created it (it is neither Send
nor Sync), like igraph’s handlers.